# Changelog

## 0.1.0-alpha.1 (2025-06-30)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/zbdpay/zbd-payments-python-sdk/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([e140140](https://github.com/zbdpay/zbd-payments-python-sdk/commit/e1401402adc0922f9d480bd4915508829a012ea6))
* **api:** update via SDK Studio ([d365689](https://github.com/zbdpay/zbd-payments-python-sdk/commit/d365689aea13350770ebb29003703506b2d93bc6))
* **api:** update via SDK Studio ([77175a0](https://github.com/zbdpay/zbd-payments-python-sdk/commit/77175a07ea0bd1874d86fecb7b82e2e2388bacb0))
* **client:** add support for aiohttp ([8788187](https://github.com/zbdpay/zbd-payments-python-sdk/commit/8788187346d655321d0f7039833533060ad23a58))


### Bug Fixes

* **ci:** correct conditional ([80e453a](https://github.com/zbdpay/zbd-payments-python-sdk/commit/80e453a6e788e1d0486512289db060a0c2116c4b))
* **ci:** release-doctor — report correct token name ([80668d2](https://github.com/zbdpay/zbd-payments-python-sdk/commit/80668d2c8e761c84183950b40f2d01319f0cbbe3))


### Chores

* change publish docs url ([ade5ab6](https://github.com/zbdpay/zbd-payments-python-sdk/commit/ade5ab6d9c14e7f91a6cbb1addf75189ae3dc42e))
* **ci:** only run for pushes and fork pull requests ([859534a](https://github.com/zbdpay/zbd-payments-python-sdk/commit/859534a6d07900299587933720f1054d5b67d036))
* configure new SDK language ([679c119](https://github.com/zbdpay/zbd-payments-python-sdk/commit/679c119fa94c1e1c88d78576c52b183be1dca2ca))
* configure new SDK language ([07173a5](https://github.com/zbdpay/zbd-payments-python-sdk/commit/07173a50fe45ea94e40ed83b04dc09384bf458e1))
* **internal:** codegen related update ([5cba4a2](https://github.com/zbdpay/zbd-payments-python-sdk/commit/5cba4a2c05d6d3a8a483ada0c22720aaeb619303))
* **tests:** skip some failing tests on the latest python versions ([680eed5](https://github.com/zbdpay/zbd-payments-python-sdk/commit/680eed5b78810d2296df2e60a3c8bf0f11c73d51))
* update SDK settings ([9be94bf](https://github.com/zbdpay/zbd-payments-python-sdk/commit/9be94bf044c25787f3832724f9f00ad05e0d5878))
